#include <Arduino.h>
#include <WiFi.h>
#include <WebServer.h>
#include <ESP32_Servo.h>


#define WIFI_SSID "ACEBOTT"  //set the WIFI name of yours
#define WIFI_PASSWORD "12345678" //set the WIFI password of yours
#define WINDOW_SERVO_PIN 13 //define pin of window's servo
#define DOOR_SERVO_PIN 4 //define pin of door's servo

WebServer server(80); //creat  the web server object
Servo servo_window; //creat the servo object for window's server
Servo servo_door; //creat the servo object for door's server

const int window_close=60; //set the servo angle for when the window is closed
const int window_open=123; //set the servo angle for when the window is opened
const int door_close=5; //set the servo angle for when the door is closed
const int door_open=100; //set the servo angle for when the window is closed

void handleRoot() { // define the callback for '/' route
  server.send(200, "text/plain", "Hello from ESP32 at "+ WiFi.localIP().toString());
}
void test(){ // define the callback for '/Test' route
  server.send(200, "text/plain", "Test_OK");
}
void openDoor() { // define the callback for '/door_on' route
  servo_door.write(door_open);
  server.send(200, "text/plain", "Open the door");
}
void closeDoor() { // define the callback for '/door_off' route
  servo_door.write(door_close);
  server.send(200, "text/plain", "close the door");
}
void openWindow() {// define the callback for '/window_on' route
  servo_window.write(window_open);
  server.send(200, "text/plain", "Open the window");
}
void closeWindow() {// define the callback for '/window_off' route
  servo_window.write(window_close);
  server.send(200, "text/plain", "close the window");
}


void setup() {
  /***** show IP address in serial monitor ****/
  Serial.begin(115200);
  WiFi.begin(WIFI_SSID, WIFI_PASSWORD);//start the wifi
  while (WiFi.status() != WL_CONNECTED) {// check if wifi is connected
    delay(1000);
    Serial.println(".");
  }
  Serial.print("IP:");
  Serial.println(WiFi.localIP());//print the ESP32 IP address
  server.on("/", handleRoot);//register the '/' route and set the callback to be executed when this route is accessed.
  server.on("/Test", test);//register the '/Test' route and set the callback to be executed when this route is accessed.
  server.on("/door_on", openDoor);//register the '/door_on' route and set the callback to be executed when this route is accessed.
  server.on("/door_off", closeDoor);//register the '/door_off' route and set the callback to be executed when this route is accessed.
  server.on("/window_on", openWindow);//register the '/window_on' route and set the callback to be executed when this route is accessed.
  server.on("/window_off", closeWindow);//register the '/door_on' route and set the callback to be executed when this route is accessed.
  server.begin();//start the web server
 
  servo_door.attach(DOOR_SERVO_PIN,500,2500);//initial the servo of door
  servo_door.write(door_close);//close the door
  delay(500);

  servo_window.attach(WINDOW_SERVO_PIN,500,2500);//initial the servo of window
  servo_window.write(window_open);//open the window
  delay(500);
  //Initialization of window servos 
}

void loop() {
  server.handleClient();//handle requests from clients
}


